#!/bin/bash
set -eo pipefail

SCRIPTPATH=$( cd $(dirname $0) ; pwd -P )

test -f $SCRIPTPATH/sas_config.osql || echo "Could not find file $SCRIPTPATH/sas_config.osql".

if [ "$SA_HOSTNAME" == "" ]; then
    echo "SA_HOSTNAME not set."
    echo "Set SA_HOSTNAME to the public facing address for the server in your service configuration or as an exported variable."
    echo "This can either be the public IP (such as 83.45.34.21) of the server or a"
    echo "hostname (such as studio.streamanalyze.com)."
    echo "Environment=SA_HOSTNAME=<public-address>"
    echo "or"
    echo "export SA_HOSTNAME=<public-address>"
    exit 1;
fi

# Make sure we add the hostname on public SA Studio port to SA_ADDRS
export SA_ADDRS=$SA_HOSTNAME:3002

if [ "$SA_FEDERATION_AUTH_SECRET" == "" ]; then
    echo "SA_FEDERATION_AUTH_SECRET not set."
    echo "Set SA_FEDERATION_AUTH_SECRET to a secret key used for signing HMAC signatures in your service configuration or as an exported variable."
    echo "Environment=SA_FEDERATION_AUTH_SECRET=<a-long-secret-string>"
    echo "or"
    echo "export SA_FEDERATION_AUTH_SECRET=<a-long-secret-string>"
    exit 1;
fi

if [ "$SA_HOME" == "" ]; then
  echo "SA_HOME variable not set."
  echo "Set SA_HOME to desired SA_HOME folder for SA Studio instance in your service configuration or as an exported variable."
  echo "Environment=SA_HOME=<path-to-sa-home>"
  echo "or"
  echo "export SA_HOME=<path-to-sa-home>"
  exit 1;
fi

if [ "$SA_ENGINE_HOME" == "" ]; then
  echo "SA_ENGINE_HOME not set."
  echo "Set SA_ENGINE_HOME in your service configuration or as an exported variable."
  echo "Environment=SA_ENGINE_HOME=<path-to-sa.engine>"
  echo "or"
  echo "export SA_ENGINE_HOME=<path-to-sa.engine>"
  exit 1
fi

export SA_ENGINE_LOCATION=${SA_ENGINE_HOME}/bin/sa.engine

echo SA_ENGINE_HOME=$SA_ENGINE_HOME
echo SA_ENGINE_LOCATION=$SA_ENGINE_HOME
echo SA_ADDRS=$SA_ADDRS
echo SA_HOSTNAME=$SA_HOSTNAME

# Create tls folder to generate certificates in.
mkdir -p ${SA_HOME}/tls | true

if [ $1 == "gen_cert" ]; then
  echo Generating certificates.
  ${SA_ENGINE_LOCATION} -O ${SCRIPTPATH}/sas_config.osql \
                        -o "generate_certs(); quit;"
  cat ${SA_HOME}/tls/cert.crt ${SA_HOME}/tls/ca.crt >> $SCRIPTPATH/nginx/cert_and_ca.crt
  cp ${SA_HOME}/tls/private.key $SCRIPTPATH/nginx/
  exit 0  
fi
if [ $1 == "sas" ]; then
echo Starting SA Engine Server
  ${SA_ENGINE_LOCATION} -O ${SCRIPTPATH}/sas_config.osql \
                      -o "configure_security();"\
                      -n server
  exit 1
fi
if [ $1 == "studio" ]; then
  echo Starting studio server.
  cd ${SA_ENGINE_HOME}/visual_analyzer
  ${SA_ENGINE_LOCATION} -X
  node index.js -csvoc=0 \
       -lisp="(load-osql \"${SCRIPTPATH}/sas_config.osql\")" \
       -lisp='(osql "configure_security()")' \
       -lisp='(cd (sa-home))' \
       -conStr=node@localhost -p=3001
  exit 1
fi
